summaryrefslogtreecommitdiff
path: root/receiver.h
diff options
context:
space:
mode:
authorKlaus Schmidinger <vdr@tvdr.de>2012-03-02 10:19:00 +0100
committerKlaus Schmidinger <vdr@tvdr.de>2012-03-02 10:19:00 +0100
commit28bc34b245ffdf0c205f0c5f2624e5c7d94d3c54 (patch)
tree94ac74945d31647fb7087e9d36e30d8d74cb40ec /receiver.h
parenta188928e6ea462e45da7c363a3098065c4691953 (diff)
downloadvdr-28bc34b245ffdf0c205f0c5f2624e5c7d94d3c54.tar.gz
vdr-28bc34b245ffdf0c205f0c5f2624e5c7d94d3c54.tar.bz2
Revised priority handling to allow receivers with a priority that is lower than that of live viewing
Diffstat (limited to 'receiver.h')
-rw-r--r--receiver.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/receiver.h b/receiver.h
index c4afcfda..ec9d8021 100644
--- a/receiver.h
+++ b/receiver.h
@@ -4,7 +4,7 @@
* See the main source file 'vdr.c' for copyright information and
* how to reach the author.
*
- * $Id: receiver.h 2.4 2012/02/25 12:49:31 kls Exp $
+ * $Id: receiver.h 2.5 2012/03/01 09:50:24 kls Exp $
*/
#ifndef __RECEIVER_H
@@ -43,15 +43,15 @@ public:
#ifdef LEGACY_CRECEIVER
cReceiver(tChannelID ChannelID, int Priority, int Pid, const int *Pids1 = NULL, const int *Pids2 = NULL, const int *Pids3 = NULL);
#endif
- cReceiver(const cChannel *Channel = NULL, int Priority = -1);
+ cReceiver(const cChannel *Channel = NULL, int Priority = MINPRIORITY);
///< Creates a new receiver for the given Channel with the given Priority.
///< If Channel is not NULL, its pids are set by a call to SetPids().
///< Otherwise pids can be added to the receiver by separate calls to the AddPid[s]
///< functions.
///< The total number of PIDs added to a receiver must not exceed MAXRECEIVEPIDS.
///< Priority may be any value in the range +/-MAXPRIORITY. Negative values indicate
///< that this cReceiver may be detached at any time (without blocking the
///< cDevice it is attached to).
virtual ~cReceiver();
bool AddPid(int Pid);
///< Adds the given Pid to the list of PIDs of this receiver.
@@ -43,15 +43,15 @@ public:
///< functions.
///< The total number of PIDs added to a receiver must not exceed MAXRECEIVEPIDS.
- ///< Priority may be any value in the range +/-MAXPRIORITY. Negative values indicate
- ///< that this cReceiver may be detached at any time (without blocking the
- ///< cDevice it is attached to).
+ ///< Priority may be any value in the range MINPRIORITY...MAXPRIORITY. Negative values indicate
+ ///< that this cReceiver may be detached at any time in favor of a timer recording
+ ///< or live viewing (without blocking the cDevice it is attached to).
virtual ~cReceiver();
bool AddPid(int Pid);